# This file is part of KDDockWidgets.
#
# SPDX-FileCopyrightText: 2020 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
# Author: Renato Araujo Oliveira Filho <renato.araujo@kdab.com>
#
# SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only
#
# Contact KDAB at <info@kdab.com> for commercial licensing options.
#

# pylint: disable=missing-module-docstring,missing-class-docstring,missing-function-docstring

from PySide2 import QtWidgets, QtGui, QtCore

# pylint: disable=too-few-public-methods


class MyWidget(QtWidgets.QWidget):
    s_images = {}

    def __init__(self, backgroundFile="", logoFile="", parent=None):
        super().__init__(parent)

        self.background = self._lookupImage(backgroundFile)
        self.logo = self._lookupImage(logoFile)
        self.setFocusPolicy(QtCore.Qt.StrongFocus)

    # pylint: disable=no-self-use
    def _lookupImage(self, imageName):
        if imageName == "":
            return None

        if imageName not in MyWidget.s_images:
            MyWidget.s_images[imageName] = QtGui.QImage(imageName)

        return MyWidget.s_images[imageName]

    def drawLogo(self, p):

        if not self.logo:
            return

        ratio = self.logo.height() / (self.logo.width() * 1.0)
        maxWidth = int(0.80 * self.size().width())
        maxHeight = int(0.80 * self.size().height())
        proposedHeight = int(maxWidth * ratio)
        if proposedHeight <= maxHeight:
            width = maxWidth
        else:
            width = int(maxHeight / ratio)

        height = int(width * ratio)
        targetLogoRect = QtCore.QRect(0, 0, width, height)
        targetLogoRect.moveCenter(self.rect().center(
        ) + QtCore.QPoint(0, -int(self.size().height() * 0.00)))
        p.drawImage(targetLogoRect, self.logo, self.logo.rect())



# This file is part of KDDockWidgets.
#
# SPDX-FileCopyrightText: 2020 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
#
# SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only
#
# Contact KDAB at <info@kdab.com> for commercial licensing options.
#

from conans import ConanFile, CMake, tools


class KDDockWidgetsConan(ConanFile):
    name = "kddockwidgets"
    version = "2.1.0"
    default_user = "kdab"
    default_channel = "stable"
    license = ("https://raw.githubusercontent.com/KDAB/KDDockWidgets/master/LICENSES/GPL-2.0-only.txt",
               "https://raw.githubusercontent.com/KDAB/KDDockWidgets/master/LICENSES/GPL-3.0-only.txt")
    author = "Klaralvdalens Datakonsult AB (KDAB) info@kdab.com"
    url = "https://github.com/KDAB/KDDockWidgets"
    description = "Advanced Dock Widget Framework for Qt"
    generators = "cmake"
    topics = ("qt", "dockwidget", "kdab")
    settings = "os", "compiler", "build_type", "arch"
    options = {
        "qt_version": "ANY",
        "build_static": [True, False],
        "build_examples": [True, False],
        "build_tests": [True, False],
        "build_python_bindings": [True, False],
        "build_for_qt6": [True, False],
    }

    default_options = {
        "qt_version": "qt/[>5.12.0]@kdab/stable",
        "build_static": False,
        "build_examples": True,
        "build_tests": False,
        "build_python_bindings": False,
        "build_for_qt6": False,
    }

    def requirements(self):
        # Check https://docs.conan.io/en/latest/reference/conanfile/attributes.html#version-ranges for more info about versioning
        self.requires(str(self.options.qt_version))

    def source(self):
        git = tools.Git(folder="")
        git.clone(self.url)

    def build(self, build_type="Release"):
        self.cmake = CMake(self, generator='Ninja', build_type=build_type)
        self.cmake.definitions["KDDockWidgets_STATIC"] = self.options.build_static
        self.cmake.definitions["KDDockWidgets_EXAMPLES"] = self.options.build_examples
        self.cmake.definitions["KDDockWidgets_TESTS"] = self.options.build_tests
        self.cmake.definitions["KDDockWidgets_PYTHON_BINDINGS"] = self.options.build_python_bindings
        self.cmake.definitions["KDDockWidgets_QT6"] = self.options.build_for_qt6
        self.cmake.configure()
        self.cmake.build()

    def package(self):
        self.cmake.install()

    def package_info(self):
        self.env_info.CMAKE_PREFIX_PATH.append(self.package_folder)

    def package_id(self):
        # Check only the major and minor version!
        self.info.requires["qt"].minor_mode()



#
# SPDX-FileCopyrightText: 2023 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
# Author: Renato Araujo Oliveira Filho <renato.araujo@kdab.com>
#
# SPDX-License-Identifier: BSD-3-Clause
#

"""
Script to fix bugs in code generated by shiboken-generator vr2
"""

import sys
import re


def removeExtraNamespaceForDefaultEnumValue(filename):
    """
    Remove namespace from default flag value
    this is a shiboken2 bug fixed on shiboken6
    """
    regex = re.compile(r"\s=\s[^\s]+::{}")
    newContent = ""
    with open(filename, encoding='utf-8') as f:
        for line in f:
            newContent += re.sub(regex, ' = {}', line)

    with open(filename, "w", encoding='utf-8') as f:
        f.write(newContent)


# Usage: <script> <list-of-files>
# It will fix the file inplace
if __name__ == '__main__':
    for fileToFix in sys.argv[1:]:
        print("Fixup: {}".format(fileToFix))
        removeExtraNamespaceForDefaultEnumValue(fileToFix)



# This file is part of KDDockWidgets.
#
# SPDX-FileCopyrightText: 2021 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
# Author: Renato Araujo <renato.araujo@kdab.com>
#
# SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only
#
# Contact KDAB at <info@kdab.com> for commercial licensing options.
#

# pylint: disable=missing-module-docstring,missing-class-docstring,missing-function-docstring

import unittest
import importlib
import inspect

from config import TstConfig


class TestImportModules(unittest.TestCase):
    def test_importModules(self):
        m = importlib.import_module(TstConfig.bindingsNamespace + '.KDDockWidgets')
        moduleSymbols = []
        for t in inspect.getmembers(m):
            moduleSymbols.append(t[0])

        symbols = ['MainWindow', 'DockWidget']
        for symbol in symbols:
            self.assertIn(symbol, moduleSymbols)


if __name__ == '__main__':
    TstConfig.initLibraryPath()
    unittest.main()



# This file is part of KDDockWidgets.
#
# SPDX-FileCopyrightText: 2020 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
# Author: Renato Araujo Oliveira Filho <renato.araujo@kdab.com>
#
# SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only
#
# Contact KDAB at <info@kdab.com> for commercial licensing options.
#

''' KDDockWidgets example (Qt6) '''

import sys

from PySide6 import QtWidgets, QtCore

# pylint: disable=no-name-in-module
from PyKDDockWidgets import KDDockWidgets

from MyWidget import MyWidget

try:
    # pylint: disable=unused-import
    import rc_assets
except ImportError:
    sys.exit(
        '''
Oops.. rc_assets needs to be generated first.
Please run:
 rcc -g python -o rc_assets.py ../../examples/dockwidgets/resources_example.qrc
 (Make sure to use the rcc from the Qt6 version used to generate the bindings!)
 On some systems rcc might be invoked as rcc-qt6.
'''
    )

if __name__ == "__main__":
    app = QtWidgets.QApplication(sys.argv)

    app.setOrganizationName("KDAB")
    app.setApplicationName("Test app")

    KDDockWidgets.initFrontend(KDDockWidgets.FrontendType.QtWidgets)
    app.setStyle(QtWidgets.QStyleFactory.create("Fusion"))

    # 1. Create our main window
    mainWindow = KDDockWidgets.MainWindow("MyMainWindow")
    mainWindow.setWindowTitle("Main Window")
    mainWindow.resize(1200, 1200)
    mainWindow.show()

    # 2. Create a dock widget, it needs a unique name
    dock1 = KDDockWidgets.DockWidget("MyDock1")
    widget1 = MyWidget("", "")
    dock1.setWidget(widget1)

    dock2 = KDDockWidgets.DockWidget("MyDock2")
    widget2 = MyWidget(":/assets/base.png", ":/assets/KDAB_bubble_fulcolor.png")
    dock2.setWidget(widget2)

    dock3 = KDDockWidgets.DockWidget("MyDock3")
    widget3 = MyWidget(":/assets/base.png", ":/assets/KDAB_bubble_fulcolor.png")
    dock3.setWidget(widget3)

    dock4 = KDDockWidgets.DockWidget("MyDock4")
    widget4 = MyWidget(":/assets/base.png", ":/assets/KDAB_bubble_fulcolor.png")
    dock4.setWidget(widget4)

    dock5 = KDDockWidgets.DockWidget("MyDock5")
    widget5 = MyWidget(":/assets/base.png", ":/assets/KDAB_bubble_fulcolor.png")
    dock5.setWidget(widget5)

    # 3. Add them to the main window
    mainWindow.addKDockWidget(dock1, KDDockWidgets.Location.Location_OnLeft)
    mainWindow.addKDockWidget(dock2, KDDockWidgets.Location.Location_OnTop)

    # 4. Add dock3 to the right of dock2
    mainWindow.addKDockWidget(dock3, KDDockWidgets.Location.Location_OnRight, dock2)

    # 5. dock4 is docked at the bottom, with 200px height
    preferredSize = QtCore.QSize(0, 200)
    mainWindow.addKDockWidget(dock4, KDDockWidgets.Location.Location_OnBottom, None, preferredSize)

    # 5. dock5 will be its own top level (floating window)
    dock5.open()

    app.exec()
